
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU Library General
# Public License along with this library; if not, write to the
# Free Foundation, Inc., 59 Temple Place, Suite 330, Boston,
# MA  02111-1307  USA

# Copyrights (C)
# for this R-port: 
#   1999 - 2004, Diethelm Wuertz, GPL
#   Diethelm Wuertz <wuertz@itp.phys.ethz.ch>
#   info@rmetrics.org
#   www.rmetrics.org
# for the code accessed (or partly included) from other R-ports:
#   see R's copyright and license files
# for the code accessed (or partly included) from contributed R-ports
# and other sources
#   see Rmetrics's copyright file


################################################################################
# FUNCTION:              NORMAL Distribution - part of R's base Package:
#  * dnorm                R: Density for the Normal Distribution
#  * pnorm                R: Probability function for the Normal Distribution
#  * qnorm                R: Quantile function for the Normal Distribution
#  * rnorm                R: Random Number Generator for the Normal Distribution  
# FUNCTION:              SKEW NORMAL DISTRIBUTION:
#  dsnorm                 Density for the skew normal Distribution
#  psnorm                 Probability function for the skew NORM
#  qsnorm                 Quantile function for the skew NORM
#  rsnorm                 Random Number Generator for the skew NORM
# FUNCTION:              NORMAL DISTRIBUTION SLIDER:
#  .normSlider            Displays Normal Distribution and RVS
################################################################################


################################################################################
# FUNCTION:              VARIANCE-1 STUDENT-T DISTRIBUTION:
#  dstd                   Density for the Student-t Distribution
#  pstd                   Probability function for the Student-t Distribution
#  qstd                   Quantile function for the Student-t Distribution
#  rstd                   Random Number Generator for the Student-t
# FUNCTION:              SKEW VARIANCE-1 STUDENT-T DISTRIBUTION:
#  dsstd                  Density for the skewed Student-t Distribution
#  psstd                  Probability function for the skewed STD
#  qsstd                  Quantile function for the skewed STD
#  rsstd                  Random Number Generator for the skewed STD
# FUNCTION:              VARIANCE-1 STUDENT-T DISTRIBUTION SLIDER:
#  .stdSlider             Displays Variance-1 Student-t Distribution and RVS
################################################################################


################################################################################
# FUNCTION:              GED DISTRIBUTION:
#  dged                   Density for the Generalized Error Distribution
#  pged                   Probability function for the GED
#  qged                   Quantile function for the GED
#  rged                   Random Number Generator for the GED
# FUNCTION:              SKEW GED DISTRIBUTION:
#  dsged                  Density for the skewed GED
#  psged                  Probability function for the skewed GED
#  qsged                  Quantile function for the skewed GED
#  rsged                  Random Number Generator for the skewed GED
# FUNCTION:              GED DISTRIBUTION SLIDER:
#  .gedSlider            Displays Generalized Error Distribution and RVS
################################################################################


################################################################################
# FUNCTION:              PARAMETER ESTIMATION:
#  normFit                Fit the parameters for a Normal distribution
#  snormFit               Fit the parameters for a skew Normal distribution
#  gedFit                 Fit the parameters for a GED distribution
#  sgedFit                Fit the parameters for a skew GED distribution
#  stdFit                 Fit the parameters for a Sudent-t distribution
#  sstdFit                Fit the parameters for a skew Sudent-t distribution
################################################################################


################################################################################
# FUNCTION:              MOMENTS:
#  absMoments             Compute absolute moments of a symmetric distribution
################################################################################



test.helpFile = 
function()
{
    # Help File:
    helpFile = function() { 
        example(GarchDistributions); return() }
    checkIdentical(
        target = class(try(helpFile())),
        current = "NULL")

    # Return Value:
    return()    
}


# ------------------------------------------------------------------------------


test.normDistribution = 
function()
{   
    # Normal Distribution:
    test = .distCheck("norm",  mean = 0, sd = 1)
    print(test)
    checkTrue(mean(test) == 1)
    
    # Skew Normal Distribution:
    test = .distCheck("snorm", mean = 0, sd = 1, xi = 1.5) 
    print(test)
    checkTrue(mean(test) == 1)
    
    # Return Value:
    return()    
}


# ------------------------------------------------------------------------------


test.stdDistribution = 
function()
{ 
    # Standardized Student-t Distribution:
    test = .distCheck("std",  mean = 0, sd = 1, nu = 5) 
    print(test)
    checkTrue(mean(test) == 1)
    
    # Skew Standardized Student-t Distribution:
    test = .distCheck("sstd", mean = 0, sd = 1, nu = 5, xi = 1.5) 
    print(test)
    checkTrue(mean(test) == 1)

    # Return Value:
    return()    
}


# ------------------------------------------------------------------------------


test.gedDistribution = 
function()
{       
    # Generalized Error Distribution:
    test = .distCheck("ged",  mean = 0, sd = 1, nu = 2) 
    print(test)
    checkTrue(mean(test) == 1)
    
    # Skew Generalized Error Distribution:
    test = .distCheck("sged", mean = 0, sd = 1, nu = 2, xi = 1.5) 
    print(test)
    checkTrue(mean(test) == 1)
    
    # Return Value:
    return()    
}


# ------------------------------------------------------------------------------


test.distributionFit = 
function()
{  
    # Parameter Estimation:
    #  normFit             Fit the parameters for a Normal distribution
    #  snormFit            Fit the parameters for a skew Normal distribution
    #  gedFit              Fit the parameters for a GED distribution
    #  sgedFit             Fit the parameters for a skew GED distribution
    #  stdFit              Fit the parameters for a Sudent-t distribution
    #  sstdFit             Fit the parameters for a skew Sudent-t distribution
    
    # Normal Distribution:
    set.seed(4711)
    x = rnorm(n = 1000, mean = 0, sd = 1)
    fit = normFit(x)
    print(fit)
    target = round(as.vector(fit$estimate), 1)
    print(target)
    current = c(0, 1)
    checkEqualsNumeric(target, current, tol = 0.1)
    
    # Skew Normal Distribution:
    set.seed(4711)
    x = rsnorm(n = 1000, mean = 0, sd = 1, xi = 1.5)
    fit = snormFit(x)
    print(fit)
    target = round(as.vector(fit$estimate), 1)
    print(target)
    current = c(0, 1, 1.5)
    checkEqualsNumeric(target, current, tol = 0.1)
    
    # Standardized Student-t Distribution:
    set.seed(4711)
    x = rstd(n = 2500, mean = 0, sd = 1, nu = 5)
    fit = stdFit(x)
    print(fit)
    target = round(as.vector(fit$estimate), 1)
    print(target)
    current = c(0, 1, 5)
    checkEqualsNumeric(target, current, tol = 0.1)
    
    # Skew Standardized Student-t Distribution:
    set.seed(4711)
    x = rsstd(n = 2500, mean = 0, sd = 1, nu = 5, xi = 1.5)
    fit = sstdFit(x)
    print(fit)
    target = round(as.vector(fit$estimate), 1)
    print(target)
    current = c(0, 1, 5, 1.5)
    checkEqualsNumeric(target, current, tol = 0.1)
    
    # Generalized Error Distribution:
    set.seed(4711)
    x = rged(1000, mean = 0, nu = 2)
    fit = gedFit(x)
    print(fit)
    target = round(as.vector(fit$estimate), 1)
    print(target)
    current = c(0, 1, 2)
    checkEqualsNumeric(target, current, tol = 0.1)
    
    # Skew Generalized Error Distribution:
    set.seed(4711)
    x = rsged(1000, mean = 0, sd = 1, nu = 2, xi = 1.5)
    fit = sgedFit(x)
    print(fit)
    target = round(as.vector(fit$estimate), 1)
    print(target)
    current = c(0, 1, 2, 1.5)
    checkEqualsNumeric(target, current, tol = 0.1)

    # Return Value:
    return()    
}

# ------------------------------------------------------------------------------


test.absMoments = 
function()
{  
    # Absolute Moments:
    #  absMoments        Compute absolute moments of a symmetric distribution
    
    # Function Call:
    #   absMoments(n, density = c("dnorm", "dged", "dstd"), ...) 
    
    ans = absMoments(1:4, "dnorm")
    
    ans = absMoments(1:4, "dstd", nu = 20)
    
    ans = absMoments(1:4, "dged", nu = 2)
}


# ------------------------------------------------------------------------------


if (FALSE) {
    require(RUnit)
    testResult <- runTestFile("C:/Rmetrics/SVN/trunk/fSeries/test/runit4A.R")
    printTextProtocol(testResult)
}
   

################################################################################
    
